@@ -605,7 +605,12 @@ class MainWindow(gtk.Window):
       import csv
       w = csv.writer(open(filename, "w"))
       for ref in self.base.selections:
-        w.writerow([ref.journal, ref.get_volume(), ref.get_issue(), ref.pub_date.month, ref.pub_date.year, ref.title, ref.authors, ref.abstract])
+        if ref.pub_date:
+          month = ref.pub_date.month
+          year  = ref.pub_date.year
+        else:
+          month = year = ""
+        w.writerow([ref.journal, ref.get_volume(), ref.get_issue(), month, year, ref.title, ref.authors, ref.abstract])
       
       
   def file_dialog(self, name, action, options, type = "xml", export = 0):
